@@ -1,6 +1,6 @@
 import json, base64, os, pickle, datetime, string, re
 
-__version__ = "0.1.4"
+__version__ = "0.1.5"
 ### from ipynb extract markdown and noted output for document organization
 
 class nbparser:
@@ -132,7 +132,7 @@ class nbparser:
         
         self.code.append(0) #number counting
         codenum = len(self.code)
-        self.source.append(f"**Code {codenum}.** : {captions}  \n")
+        self.source.append(f"**Code {codenum}.** {captions}  \n")
         if output:
             self.source.append("---")
         self.source.append(f"```python\n{''.join(codecell['source'])}\n```")
@@ -185,7 +185,7 @@ class nbparser:
         #delete blank line
         table = "\n".join([line for line in "".join(table).split("\n") if line]) 
         self.source.append("".join(table))
-        self.source.append(f"\n**Table {len(self.table)}** {captions}  \n<br><br>\n")
+        self.source.append(f"\n**Table {len(self.table)}.** {captions}  \n<br><br>\n")
 
     def toc_source(self):
         """Generate markdown source of `Table of Contents` from header in `self.TOC`.
